@@ -1,4 +1,4 @@
-"sortMatrix" <- 
+`sortMatrix` <- 
 function(submatrix) {
     if (all(is.na(submatrix)) | all(!is.na(submatrix)) | !is.matrix(submatrix)) {
         submatrix
